==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/KPIRANGEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for KPIRANGEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="KPIRANGEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HOMEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOWVALUE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HIGHVALUE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SCORE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ICON" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "KPIRANGEID_Type", propOrder = {
    "homeid",
    "lowvalue",
    "highvalue",
    "score",
    "icon",
    "description"
})
public class KPIRANGEID_Type {

    @XmlElement(name = "HOMEID", required = true)
    protected HOMEID_Type homeid;
    @XmlElement(name = "LOWVALUE", required = true)
    protected QUANTITY lowvalue;
    @XmlElement(name = "HIGHVALUE", required = true)
    protected QUANTITY highvalue;
    @XmlElement(name = "SCORE")
    protected Long score;
    @XmlElement(name = "ICON")
    protected String icon;
    @XmlElement(name = "DESCRIPTION", required = true)
    protected String description;

    /**
     * Gets the value of the homeid property.
     * 
     * @return
     *     possible object is
     *     {@link HOMEID_Type }
     *     
     */
    public HOMEID_Type getHOMEID() {
        return homeid;
    }

    /**
     * Sets the value of the homeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link HOMEID_Type }
     *     
     */
    public void setHOMEID(HOMEID_Type value) {
        this.homeid = value;
    }

    /**
     * Gets the value of the lowvalue property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getLOWVALUE() {
        return lowvalue;
    }

    /**
     * Sets the value of the lowvalue property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setLOWVALUE(QUANTITY value) {
        this.lowvalue = value;
    }

    /**
     * Gets the value of the highvalue property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getHIGHVALUE() {
        return highvalue;
    }

    /**
     * Sets the value of the highvalue property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setHIGHVALUE(QUANTITY value) {
        this.highvalue = value;
    }

    /**
     * Gets the value of the score property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getSCORE() {
        return score;
    }

    /**
     * Sets the value of the score property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setSCORE(Long value) {
        this.score = value;
    }

    /**
     * Gets the value of the icon property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getICON() {
        return icon;
    }

    /**
     * Sets the value of the icon property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setICON(String value) {
        this.icon = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-11.4-9-sources.jar: net/datastream/schemas/mp_fields/KPIRANGEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour KPIRANGEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="KPIRANGEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HOMEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOWVALUE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HIGHVALUE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SCORE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ICON" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "KPIRANGEID_Type", propOrder = {
    "homeid",
    "lowvalue",
    "highvalue",
    "score",
    "icon",
    "description"
})
public class KPIRANGEID_Type {

    @XmlElement(name = "HOMEID", required = true)
    protected HOMEID_Type homeid;
    @XmlElement(name = "LOWVALUE", required = true)
    protected QUANTITY lowvalue;
    @XmlElement(name = "HIGHVALUE", required = true)
    protected QUANTITY highvalue;
    @XmlElement(name = "SCORE")
    protected Long score;
    @XmlElement(name = "ICON")
    protected String icon;
    @XmlElement(name = "DESCRIPTION", required = true)
    protected String description;

    /**
     * Obtient la valeur de la propriété homeid.
     * 
     * @return
     *     possible object is
     *     {@link HOMEID_Type }
     *     
     */
    public HOMEID_Type getHOMEID() {
        return homeid;
    }

    /**
     * Définit la valeur de la propriété homeid.
     * 
     * @param value
     *     allowed object is
     *     {@link HOMEID_Type }
     *     
     */
    public void setHOMEID(HOMEID_Type value) {
        this.homeid = value;
    }

    /**
     * Obtient la valeur de la propriété lowvalue.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getLOWVALUE() {
        return lowvalue;
    }

    /**
     * Définit la valeur de la propriété lowvalue.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setLOWVALUE(QUANTITY value) {
        this.lowvalue = value;
    }

    /**
     * Obtient la valeur de la propriété highvalue.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getHIGHVALUE() {
        return highvalue;
    }

    /**
     * Définit la valeur de la propriété highvalue.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setHIGHVALUE(QUANTITY value) {
        this.highvalue = value;
    }

    /**
     * Obtient la valeur de la propriété score.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getSCORE() {
        return score;
    }

    /**
     * Définit la valeur de la propriété score.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setSCORE(Long value) {
        this.score = value;
    }

    /**
     * Obtient la valeur de la propriété icon.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getICON() {
        return icon;
    }

    /**
     * Définit la valeur de la propriété icon.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setICON(String value) {
        this.icon = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
